@@ -1,27 +1,31 @@
 """CLI enabler for pytrafikverket."""
+
+from __future__ import annotations
+
 import argparse
 import asyncio
+import json
 from datetime import datetime
+from typing import Any
 
 import aiohttp
-import async_timeout
-from pytrafikverket.trafikverket import Trafikverket
-from pytrafikverket.trafikverket_train import TrafikverketTrain
-from pytrafikverket.trafikverket_weather import TrafikverketWeather
-from pytrafikverket.trafikverket_ferry import TrafikverketFerry
-import inspect
+
+from .const import (
+    DATE_TIME_INPUT,
+    GET_FERRY_ROUTE,
+    GET_NEXT_FERRY_STOP,
+    GET_NEXT_TRAIN_STOP,
+    GET_TRAIN_STOP,
+    GET_WEATHER,
+    SEARCH_FOR_FERRY_ROUTE,
+    SEARCH_FOR_STATION,
+)
+from .trafikverket_ferry import TrafikverketFerry
+from .trafikverket_train import TrafikverketTrain
+from .trafikverket_weather import TrafikverketWeather
 
 
-SEARCH_FOR_STATION = "search-for-station"
-GET_TRAIN_STOP = "get-train-stop"
-GET_NEXT_TRAIN_STOP = "get-next-train-stop"
-GET_WEATHER = "get-weather"
-GET_FERRY_ROUTE = "get-ferry-route"
-SEARCH_FOR_FERRY_ROUTE = "search-for-ferry-route"
-GET_NEXT_FERRY_STOP = "get-next-ferry-stop"
-DATE_TIME_INPUT = "%Y-%m-%dT%H:%M:%S"
-
-async def async_main(loop):
+async def async_main(loop: Any) -> None:
     """Set up function to handle input and get data to present."""
     async with aiohttp.ClientSession(loop=loop) as session:
         parser = argparse.ArgumentParser(
@@ -29,7 +33,8 @@ async def async_main(loop):
         )
         parser.add_argument("-key", type=str, required=True)
         parser.add_argument(
-            "-method", required=True,
+            "-method",
+            required=True,
             choices=(
                 SEARCH_FOR_STATION,
                 GET_TRAIN_STOP,
@@ -48,52 +53,61 @@ async def async_main(loop):
         parser.add_argument("-from-harbor", type=str)
         parser.add_argument("-to-harbor", type=str)
         parser.add_argument("-train-product", type=str)
+        parser.add_argument(
+            "-exclude-canceled-trains",
+            action=argparse.BooleanOptionalAction,
+            default=False,
+        )
 
-        args = parser.parse_args()
+        async with asyncio.timeout(10):
+            args = parser.parse_args()
+            train_api = TrafikverketTrain(session, args.key)
+            weather_api = TrafikverketWeather(session, args.key)
+            ferry_api = TrafikverketFerry(session, args.key)
 
-        train_api = TrafikverketTrain(session, args.key)
-        weather_api = TrafikverketWeather(session, args.key)
-        ferry_api = TrafikverketFerry(session, args.key)
-        with async_timeout.timeout(10):
             if args.method == SEARCH_FOR_STATION:
                 if args.station is None:
                     raise ValueError("-station is required")
                 stations = await train_api.async_search_train_stations(args.station)
                 for station in stations:
-                    print("Name: " + station.name + ", Signature: "
-                          + station.signature
-                          + ", Advertised: " + station.advertised)
+                    print_values(station)
             elif args.method == GET_TRAIN_STOP:
-                from_station = await train_api.async_get_train_station(
+                from_station = await train_api.async_search_train_station(
                     args.from_station
                 )
-                to_station = await train_api.async_get_train_station(args.to_station)
-                print("from_station_signature: " + from_station.signature)
-                print("to_station_signature:   " + to_station.signature)
+                to_station = await train_api.async_search_train_station(args.to_station)
+                print(f"from_station_signature: {from_station.signature}")  # noqa: T201
+                print(f"to_station_signature:   {to_station.signature}")  # noqa: T201
 
                 time = datetime.strptime(args.date_time, DATE_TIME_INPUT)
 
                 train_stop = await train_api.async_get_train_stop(
-                    from_station, to_station, time, product_description=args.train_product
+                    from_station,
+                    to_station,
+                    time,
+                    product_description=args.train_product,
+                    exclude_canceled=args.exclude_canceled_trains,
                 )
                 print_values(train_stop)
 
             elif args.method == GET_NEXT_TRAIN_STOP:
-                from_station = await train_api.async_get_train_station(
+                from_station = await train_api.async_search_train_station(
                     args.from_station
                 )
-                to_station = await train_api.async_get_train_station(args.to_station)
-                print("from_station_signature: " + from_station.signature)
-                print("to_station_signature:   " + to_station.signature)
+                to_station = await train_api.async_search_train_station(args.to_station)
+                print(f"from_station_signature: {from_station.signature}")  # noqa: T201
+                print(f"to_station_signature:   {to_station.signature}")  # noqa: T201
 
                 if args.date_time is not None:
-                    time = datetime.strptime(
-                        args.date_time, DATE_TIME_INPUT
-                    )
+                    time = datetime.strptime(args.date_time, DATE_TIME_INPUT)
                 else:
                     time = datetime.now()
                 train_stop = await train_api.async_get_next_train_stop(
-                    from_station, to_station, time, product_description=args.train_product
+                    from_station,
+                    to_station,
+                    time,
+                    product_description=args.train_product,
+                    exclude_canceled=args.exclude_canceled_trains,
                 )
                 print_values(train_stop)
 
@@ -121,7 +135,7 @@ async def async_main(loop):
                 routes = await ferry_api.async_search_ferry_routes(args.route)
                 for route in routes:
                     print_values(route)
-                    print(route.name + " " + route.id)
+                    print(f"{route.ferry_route_name} {route.ferry_route_id}")  # noqa: T201
 
             elif args.method == GET_NEXT_FERRY_STOP:
                 if args.from_harbor is None:
@@ -130,9 +144,7 @@ async def async_main(loop):
                          (ex. -from-harbor "Ekerö")'
                     )
                 if args.date_time is not None:
-                    time = datetime.strptime(
-                        args.date_time, DATE_TIME_INPUT
-                    )
+                    time = datetime.strptime(args.date_time, DATE_TIME_INPUT)
                 else:
                     time = datetime.now()
 
@@ -142,15 +154,12 @@ async def async_main(loop):
                 print_values(ferry_stop)
 
 
-def print_values(object):
+def print_values(result: Any) -> None:
     """Print out values for all object members."""
-    for i in inspect.getmembers(object):
-        if not i[0].startswith("_"):
-            if not inspect.ismethod(i[1]):
-                print(i[0], "=", i[1])
+    print(json.dumps(result.__dict__, indent=4, ensure_ascii=False))  # noqa: T201
 
 
-def main():
+def main() -> None:
     """Initialize the loop."""
     loop = asyncio.get_event_loop()
     loop.run_until_complete(async_main(loop))
